from setuptools import setup

setup(name='notafunnytest',
      version='1.0',
      description='The funniest joke in the world',
      url='https://github.com/LorenzoPeve/funnytest',
      author='Nostradamus',
      author_email='doesnotexist@gmail.com',
      license='MIT',
      packages=['notafunnytest'],
      zip_safe=False)